"""
This Source Code Form is subject to the terms of the Mozilla Public License, v. 2.0.
If a copy of the MPL was not distributed with this file, You can obtain one at https://mozilla.org/MPL/2.0/.
"""

import os
from typing import Optional

from sleet.constants import WarcraftExpansion
from sleet.exceptions import CredentialError
from sleet.hearthstone import HearthstoneAPI
from sleet.warcraft import WarcraftAPI


class BlizzardAPI:
    def __init__(self, region: str, *, client_id: Optional[str] = None, client_secret: Optional[str] = None):
        client_id = client_id or os.getenv("BNET_CLIENT_ID")
        client_secret = client_secret or os.getenv("BNET_CLIENT_SECRET")

        if not client_id:
            raise CredentialError("BNET_CLIENT_ID environment variable must be present or client_id "
                                  "argument must be set.")

        if not client_secret:
            raise CredentialError("BNET_CLIENT_SECRET environment variable must be present or client_secret "
                                  "argument must be set.")

        self.hearthstone = HearthstoneAPI(region=region,
                                          client_id=client_id,
                                          client_secret=client_secret)
        self.wow = WarcraftAPI(region=region,
                               client_id=client_id,
                               client_secret=client_secret,
                               expansion=WarcraftExpansion.RETAIL)
        self.wow_classic = WarcraftAPI(region=region,
                                       client_id=client_id,
                                       client_secret=client_secret,
                                       expansion=WarcraftExpansion.CLASSIC)
        self.wow_tbcc = WarcraftAPI(region=region,
                                    client_id=client_id,
                                    client_secret=client_secret,
                                    expansion=WarcraftExpansion.TBCC)
