"""
This Source Code Form is subject to the terms of the Mozilla Public License, v. 2.0.
If a copy of the MPL was not distributed with this file, You can obtain one at https://mozilla.org/MPL/2.0/.
"""

import logging
from typing import TYPE_CHECKING, Iterable

from sleet.constants import API_VALID_REGIONS

if TYPE_CHECKING:
    from sleet.warcraft.api import WarcraftExpansion

logger = logging.getLogger(__name__)


class SleetError(Exception):
    pass


class APIStatusError(SleetError):
    def __init__(self, status_code: int):
        super().__init__(f"Blizzard API returned HTTP Status Code {status_code}.")
        self.status_code = status_code


class CredentialError(SleetError):
    pass


class RegionError(SleetError):
    def __init__(self, region: str):
        super().__init__(f"{region} is not a valid region. Valid regions are {', '.join(API_VALID_REGIONS)}.")


class WarcraftExpansionError(SleetError):
    def __init__(self, function: str, expansion: "WarcraftExpansion", valid_expansions: Iterable["WarcraftExpansion"]):
        super().__init__(f"{function}() is not a valid {expansion.value} API function. "
                         f"{function}() supports {', '.join((ve.value for ve in valid_expansions))}.")
